@@ -9,36 +9,36 @@ import unittest
 
 from tests.base import BaseTestCase
 
+from pyasn1.error import PyAsn1Error
 from pyasn1.type import tag
 from pyasn1.type import namedtype
 from pyasn1.type import opentype
 from pyasn1.type import univ
 from pyasn1.codec.der import encoder
-from pyasn1.compat.octets import ints2octs
 
 
 class OctetStringEncoderTestCase(BaseTestCase):
     def testDefModeShort(self):
         assert encoder.encode(
             univ.OctetString('Quick brown fox')
-        ) == ints2octs((4, 15, 81, 117, 105, 99, 107, 32, 98, 114, 111, 119, 110, 32, 102, 111, 120))
+        ) == bytes((4, 15, 81, 117, 105, 99, 107, 32, 98, 114, 111, 119, 110, 32, 102, 111, 120))
 
     def testDefModeLong(self):
         assert encoder.encode(
             univ.OctetString('Q' * 10000)
-        ) == ints2octs((4, 130, 39, 16) + (81,) * 10000)
+        ) == bytes((4, 130, 39, 16) + (81,) * 10000)
 
 
 class BitStringEncoderTestCase(BaseTestCase):
     def testDefModeShort(self):
         assert encoder.encode(
             univ.BitString((1,))
-        ) == ints2octs((3, 2, 7, 128))
+        ) == bytes((3, 2, 7, 128))
 
     def testDefModeLong(self):
         assert encoder.encode(
             univ.BitString((1,) * 80000)
-        ) == ints2octs((3, 130, 39, 17, 0) + (255,) * 10000)
+        ) == bytes((3, 130, 39, 17, 0) + (255,) * 10000)
 
 
 class SetOfEncoderTestCase(BaseTestCase):
@@ -52,28 +52,28 @@ class SetOfEncoderTestCase(BaseTestCase):
         self.s.append('a')
         self.s.append('ab')
 
-        assert encoder.encode(self.s) == ints2octs((49, 7, 4, 1, 97, 4, 2, 97, 98))
+        assert encoder.encode(self.s) == bytes((49, 7, 4, 1, 97, 4, 2, 97, 98))
 
     def testDefMode2(self):
         self.s.clear()
         self.s.append('ab')
         self.s.append('a')
 
-        assert encoder.encode(self.s) == ints2octs((49, 7, 4, 1, 97, 4, 2, 97, 98))
+        assert encoder.encode(self.s) == bytes((49, 7, 4, 1, 97, 4, 2, 97, 98))
 
     def testDefMode3(self):
         self.s.clear()
         self.s.append('b')
         self.s.append('a')
 
-        assert encoder.encode(self.s) == ints2octs((49, 6, 4, 1, 97, 4, 1, 98))
+        assert encoder.encode(self.s) == bytes((49, 6, 4, 1, 97, 4, 1, 98))
 
     def testDefMode4(self):
         self.s.clear()
         self.s.append('a')
         self.s.append('b')
 
-        assert encoder.encode(self.s) == ints2octs((49, 6, 4, 1, 97, 4, 1, 98))
+        assert encoder.encode(self.s) == bytes((49, 6, 4, 1, 97, 4, 1, 98))
 
 
 class SetWithAlternatingChoiceEncoderTestCase(BaseTestCase):
@@ -93,12 +93,12 @@ class SetWithAlternatingChoiceEncoderTestCase(BaseTestCase):
     def testComponentsOrdering1(self):
         self.s.setComponentByName('status')
         self.s.getComponentByName('status').setComponentByPosition(0, 'A')
-        assert encoder.encode(self.s) == ints2octs((49, 6, 2, 1, 5, 4, 1, 65))
+        assert encoder.encode(self.s) == bytes((49, 6, 2, 1, 5, 4, 1, 65))
 
     def testComponentsOrdering2(self):
         self.s.setComponentByName('status')
         self.s.getComponentByName('status').setComponentByPosition(1, True)
-        assert encoder.encode(self.s) == ints2octs((49, 6, 1, 1, 255, 2, 1, 5))
+        assert encoder.encode(self.s) == bytes((49, 6, 1, 1, 255, 2, 1, 5))
 
 
 class SetWithTaggedChoiceEncoderTestCase(BaseTestCase):
@@ -121,7 +121,7 @@ class SetWithTaggedChoiceEncoderTestCase(BaseTestCase):
         s.setComponentByName('name', 'A')
         s.getComponentByName('customer').setComponentByName('premium', True)
 
-        assert encoder.encode(s) == ints2octs((49, 6, 1, 1, 255, 4, 1, 65))
+        assert encoder.encode(s) == bytes((49, 6, 1, 1, 255, 4, 1, 65))
 
     def testWithTaggedChoice(self):
 
@@ -141,7 +141,7 @@ class SetWithTaggedChoiceEncoderTestCase(BaseTestCase):
         s.setComponentByName('name', 'A')
         s.getComponentByName('customer').setComponentByName('premium', True)
 
-        assert encoder.encode(s) == ints2octs((49, 8, 4, 1, 65, 167, 3, 1, 1, 255))
+        assert encoder.encode(s) == bytes((49, 8, 4, 1, 65, 167, 3, 1, 1, 255))
 
 
 class SequenceEncoderWithUntaggedOpenTypesTestCase(BaseTestCase):
@@ -166,7 +166,7 @@ class SequenceEncoderWithUntaggedOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1] = univ.Integer(12)
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 5, 2, 1, 1, 49, 50)
         )
 
@@ -176,7 +176,7 @@ class SequenceEncoderWithUntaggedOpenTypesTestCase(BaseTestCase):
         self.s[0] = 2
         self.s[1] = univ.OctetString('quick brown')
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 14, 2, 1, 2, 113, 117, 105, 99, 107, 32,
              98, 114, 111, 119, 110)
         )
@@ -228,7 +228,7 @@ class SequenceEncoderWithImplicitlyTaggedOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1] = univ.Integer(12)
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 9, 2, 1, 1, 131, 4, 131, 2, 49, 50)
         )
 
@@ -255,7 +255,7 @@ class SequenceEncoderWithExplicitlyTaggedOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1] = univ.Integer(12)
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 9, 2, 1, 1, 163, 4, 163, 2, 49, 50)
         )
 
@@ -283,7 +283,7 @@ class SequenceEncoderWithUntaggedSetOfOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1].append(univ.Integer(12))
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 7, 2, 1, 1, 49, 2, 49, 50)
         )
 
@@ -293,7 +293,7 @@ class SequenceEncoderWithUntaggedSetOfOpenTypesTestCase(BaseTestCase):
         self.s[0] = 2
         self.s[1].append(univ.OctetString('quick brown'))
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 16, 2, 1, 2, 49, 11, 113, 117, 105, 99, 107, 32, 98, 114,
              111, 119, 110)
         )
@@ -349,7 +349,7 @@ class SequenceEncoderWithImplicitlyTaggedSetOfOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1].append(univ.Integer(12))
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 11, 2, 1, 1, 49, 6, 131, 4, 131, 2, 49, 50)
         )
 
@@ -379,7 +379,7 @@ class SequenceEncoderWithExplicitlyTaggedSetOfOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1].append(univ.Integer(12))
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 11, 2, 1, 1, 49, 6, 163, 4, 163, 2, 49, 50)
         )
 
@@ -448,31 +448,31 @@ class NestedOptionalSequenceEncoderTestCase(BaseTestCase):
 
     def testDefModeOptionalWithDefaultAndOptional(self):
         s = self.__initOptionalWithDefaultAndOptional()
-        assert encoder.encode(s) == ints2octs((48, 11, 48, 9, 4, 4, 116, 101, 115, 116, 2, 1, 123))
+        assert encoder.encode(s) == bytes((48, 11, 48, 9, 4, 4, 116, 101, 115, 116, 2, 1, 123))
 
     def testDefModeOptionalWithDefault(self):
         s = self.__initOptionalWithDefault()
-        assert encoder.encode(s) == ints2octs((48, 5, 48, 3, 2, 1, 123))
+        assert encoder.encode(s) == bytes((48, 5, 48, 3, 2, 1, 123))
 
     def testDefModeOptionalWithOptional(self):
         s = self.__initOptionalWithOptional()
-        assert encoder.encode(s) == ints2octs((48, 8, 48, 6, 4, 4, 116, 101, 115, 116))
+        assert encoder.encode(s) == bytes((48, 8, 48, 6, 4, 4, 116, 101, 115, 116))
 
     def testDefModeOptional(self):
         s = self.__initOptional()
-        assert encoder.encode(s) == ints2octs((48, 0))
+        assert encoder.encode(s) == bytes((48, 0))
 
     def testDefModeDefaultWithDefaultAndOptional(self):
         s = self.__initDefaultWithDefaultAndOptional()
-        assert encoder.encode(s) == ints2octs((48, 11, 48, 9, 4, 4, 116, 101, 115, 116, 2, 1, 123))
+        assert encoder.encode(s) == bytes((48, 11, 48, 9, 4, 4, 116, 101, 115, 116, 2, 1, 123))
 
     def testDefModeDefaultWithDefault(self):
         s = self.__initDefaultWithDefault()
-        assert encoder.encode(s) == ints2octs((48, 8, 48, 6, 4, 4, 116, 101, 115, 116))
+        assert encoder.encode(s) == bytes((48, 8, 48, 6, 4, 4, 116, 101, 115, 116))
 
     def testDefModeDefaultWithOptional(self):
         s = self.__initDefaultWithOptional()
-        assert encoder.encode(s) == ints2octs((48, 5, 48, 3, 2, 1, 123))
+        assert encoder.encode(s) == bytes((48, 5, 48, 3, 2, 1, 123))
 
 
 class NestedOptionalChoiceEncoderTestCase(BaseTestCase):
@@ -523,19 +523,19 @@ class NestedOptionalChoiceEncoderTestCase(BaseTestCase):
 
     def testDefModeOptionalWithDefaultAndOptional(self):
         s = self.__initOptionalWithDefaultAndOptional()
-        assert encoder.encode(s) == ints2octs((48, 11, 48, 9, 4, 4, 116, 101, 115, 116, 2, 1, 123))
+        assert encoder.encode(s) == bytes((48, 11, 48, 9, 4, 4, 116, 101, 115, 116, 2, 1, 123))
 
     def testDefModeOptionalWithDefault(self):
         s = self.__initOptionalWithDefault()
-        assert encoder.encode(s) == ints2octs((48, 5, 48, 3, 2, 1, 123))
+        assert encoder.encode(s) == bytes((48, 5, 48, 3, 2, 1, 123))
 
     def testDefModeOptionalWithOptional(self):
         s = self.__initOptionalWithOptional()
-        assert encoder.encode(s) == ints2octs((48, 8, 48, 6, 4, 4, 116, 101, 115, 116))
+        assert encoder.encode(s) == bytes((48, 8, 48, 6, 4, 4, 116, 101, 115, 116))
 
     def testDefModeOptional(self):
         s = self.__initOptional()
-        assert encoder.encode(s) == ints2octs((48, 0))
+        assert encoder.encode(s) == bytes((48, 0))
 
 
 class NestedOptionalSequenceOfEncoderTestCase(BaseTestCase):
@@ -565,11 +565,11 @@ class NestedOptionalSequenceOfEncoderTestCase(BaseTestCase):
 
     def testDefModeOptionalWithValue(self):
         s = self.__initOptionalWithValue()
-        assert encoder.encode(s) == ints2octs((48, 8, 48, 6, 4, 4, 116, 101, 115, 116))
+        assert encoder.encode(s) == bytes((48, 8, 48, 6, 4, 4, 116, 101, 115, 116))
 
     def testDefModeOptional(self):
         s = self.__initOptional()
-        assert encoder.encode(s) == ints2octs((48, 0))
+        assert encoder.encode(s) == bytes((48, 0))
 
 
 class EmptyInnerFieldOfSequenceEncoderTestCase(BaseTestCase):
@@ -583,7 +583,7 @@ class EmptyInnerFieldOfSequenceEncoderTestCase(BaseTestCase):
 
         self.s.clear()
         self.s[0] = ''
-        assert encoder.encode(self.s) == ints2octs((48, 2, 5, 0))
+        assert encoder.encode(self.s) == bytes((48, 2, 5, 0))
 
     def testUninitializedOptionalNullIsNotEncoded(self):
         self.s = univ.Sequence(
@@ -593,7 +593,7 @@ class EmptyInnerFieldOfSequenceEncoderTestCase(BaseTestCase):
         )
 
         self.s.clear()
-        assert encoder.encode(self.s) == ints2octs((48, 0))
+        assert encoder.encode(self.s) == bytes((48, 0))
 
     def testInitializedDefaultNullIsNotEncoded(self):
         self.s = univ.Sequence(
@@ -604,7 +604,7 @@ class EmptyInnerFieldOfSequenceEncoderTestCase(BaseTestCase):
 
         self.s.clear()
         self.s[0] = ''
-        assert encoder.encode(self.s) == ints2octs((48, 0))
+        assert encoder.encode(self.s) == bytes((48, 0))
 
     def testInitializedOptionalOctetStringIsEncoded(self):
         self.s = univ.Sequence(
@@ -615,7 +615,7 @@ class EmptyInnerFieldOfSequenceEncoderTestCase(BaseTestCase):
 
         self.s.clear()
         self.s[0] = ''
-        assert encoder.encode(self.s) == ints2octs((48, 2, 4, 0))
+        assert encoder.encode(self.s) == bytes((48, 2, 4, 0))
 
     def testUninitializedOptionalOctetStringIsNotEncoded(self):
         self.s = univ.Sequence(
@@ -625,7 +625,7 @@ class EmptyInnerFieldOfSequenceEncoderTestCase(BaseTestCase):
         )
 
         self.s.clear()
-        assert encoder.encode(self.s) == ints2octs((48, 0))
+        assert encoder.encode(self.s) == bytes((48, 0))
 
     def testInitializedDefaultOctetStringIsNotEncoded(self):
         self.s = univ.Sequence(
@@ -636,7 +636,7 @@ class EmptyInnerFieldOfSequenceEncoderTestCase(BaseTestCase):
 
         self.s.clear()
         self.s[0] = ''
-        assert encoder.encode(self.s) == ints2octs((48, 0))
+        assert encoder.encode(self.s) == bytes((48, 0))
 
 
 class ClassConstructorTestCase(BaseTestCase):
