@@ -18,7 +18,6 @@ from pyasn1.type import constraint
 from pyasn1.type import namedtype
 from pyasn1.type import namedval
 from pyasn1.type import error
-from pyasn1.compat.octets import str2octs, ints2octs, octs2ints, octs2str
 from pyasn1.error import PyAsn1Error
 from pyasn1.error import PyAsn1UnicodeEncodeError, PyAsn1UnicodeDecodeError
 
@@ -200,25 +199,17 @@ class IntegerTestCase(BaseTestCase):
     def testDivInt(self):
         assert univ.Integer(4) / 2 == 2, '__div__() fails'
 
-    if sys.version_info[0] > 2:
-        def testDivFloat(self):
-            assert univ.Integer(3) / 2 == 1.5, '__div__() fails'
+    def testDivFloat(self):
+        assert univ.Integer(3) / 2 == 1.5, '__div__() fails'
 
-        def testRdivFloat(self):
-            assert 3 / univ.Integer(2) == 1.5, '__rdiv__() fails'
-    else:
-        def testDivFloat(self):
-            assert univ.Integer(3) / 2 == 1, '__div__() fails'
-
-        def testRdivFloat(self):
-            assert 3 / univ.Integer(2) == 1, '__rdiv__() fails'
+    def testRdivFloat(self):
+        assert 3 / univ.Integer(2) == 1.5, '__rdiv__() fails'
 
     def testRdivInt(self):
         assert 6 / univ.Integer(3) == 2, '__rdiv__() fails'
 
-    if sys.version_info[0] > 2:
-        def testTrueDiv(self):
-            assert univ.Integer(3) / univ.Integer(2) == 1.5, '__truediv__() fails'
+    def testTrueDiv(self):
+        assert univ.Integer(3) / univ.Integer(2) == 1.5, '__truediv__() fails'
 
     def testFloorDiv(self):
         assert univ.Integer(3) // univ.Integer(2) == 1, '__floordiv__() fails'
@@ -430,7 +421,7 @@ class BitStringTestCase(BaseTestCase):
         assert list(reversed(univ.BitString([0, 0, 1]))) == list(univ.BitString([1, 0, 0]))
 
     def testAsOctets(self):
-        assert self.b.clone(hexValue='A98A').asOctets() == ints2octs((0xa9, 0x8a)), 'testAsOctets() fails'
+        assert self.b.clone(hexValue='A98A').asOctets() == bytes((0xa9, 0x8a)), 'testAsOctets() fails'
 
     def testAsInts(self):
         assert self.b.clone(hexValue='A98A').asNumbers() == (0xa9, 0x8a), 'testAsNumbers() fails'
@@ -474,9 +465,9 @@ class OctetStringWithUnicodeMixIn(object):
     encoding = 'us-ascii'
 
     def setUp(self):
-        self.pythonString = ints2octs(self.initializer).decode(self.encoding)
+        self.pythonString = bytes(self.initializer).decode(self.encoding)
         self.encodedPythonString = self.pythonString.encode(self.encoding)
-        self.numbersString = tuple(octs2ints(self.encodedPythonString))
+        self.numbersString = tuple(self.encodedPythonString)
 
     def testInit(self):
         assert univ.OctetString(self.encodedPythonString) == self.encodedPythonString, '__init__() fails'
@@ -486,17 +477,10 @@ class OctetStringWithUnicodeMixIn(object):
             assert univ.OctetString(univ.Integer(123)) == univ.OctetString('123')
 
     def testSerialised(self):
-        if sys.version_info[0] < 3:
-            assert str(univ.OctetString(self.encodedPythonString, encoding=self.encoding)) == self.encodedPythonString, '__str__() fails'
-        else:
-            assert bytes(univ.OctetString(self.encodedPythonString, encoding=self.encoding)) == self.encodedPythonString, '__str__() fails'
+        assert bytes(univ.OctetString(self.encodedPythonString, encoding=self.encoding)) == self.encodedPythonString, '__str__() fails'
 
     def testPrintable(self):
-        if sys.version_info[0] < 3:
-            assert str(univ.OctetString(self.encodedPythonString, encoding=self.encoding)) == self.encodedPythonString, '__str__() fails'
-            assert unicode(univ.OctetString(self.pythonString, encoding=self.encoding)) == self.pythonString, 'unicode init fails'
-        else:
-            assert str(univ.OctetString(self.pythonString, encoding=self.encoding)) == self.pythonString, 'unicode init fails'
+        assert str(univ.OctetString(self.pythonString, encoding=self.encoding)) == self.pythonString, 'unicode init fails'
 
     def testSeq(self):
         assert univ.OctetString(self.encodedPythonString)[0] == self.encodedPythonString[0], '__getitem__() fails'
@@ -538,13 +522,9 @@ class OctetStringWithAsciiTestCase(OctetStringWithUnicodeMixIn, BaseTestCase):
 
 class OctetStringUnicodeErrorTestCase(BaseTestCase):
     def testEncodeError(self):
-        serialized = ints2octs((0xff, 0xfe))
+        serialized = bytes((0xff, 0xfe))
 
-        if sys.version_info < (3, 0):
-            text = serialized.decode('iso-8859-1')
-
-        else:
-            text = octs2str(serialized)
+        text = serialized.decode('iso-8859-1')
 
         try:
             univ.OctetString(text, encoding='us-ascii')
@@ -553,16 +533,12 @@ class OctetStringUnicodeErrorTestCase(BaseTestCase):
             pass
 
     def testDecodeError(self):
-        serialized = ints2octs((0xff, 0xfe))
+        serialized = bytes((0xff, 0xfe))
 
         octetString = univ.OctetString(serialized, encoding='us-ascii')
 
         try:
-            if sys.version_info < (3, 0):
-                unicode(octetString)
-
-            else:
-                str(octetString)
+            str(octetString)
 
         except PyAsn1UnicodeDecodeError:
             pass
@@ -578,13 +554,9 @@ class OctetStringWithUtf16TestCase(OctetStringWithUnicodeMixIn, BaseTestCase):
     encoding = 'utf-16-be'
 
 
-if sys.version_info[0] > 2:
-
-    # Somehow comparison of UTF-32 encoded strings does not work in Py2
-
-    class OctetStringWithUtf32TestCase(OctetStringWithUnicodeMixIn, BaseTestCase):
-        initializer = (0, 0, 4, 48, 0, 0, 4, 49, 0, 0, 4, 50)
-        encoding = 'utf-32-be'
+class OctetStringWithUtf32TestCase(OctetStringWithUnicodeMixIn, BaseTestCase):
+    initializer = (0, 0, 4, 48, 0, 0, 4, 49, 0, 0, 4, 50)
+    encoding = 'utf-32-be'
 
 
 class OctetStringTestCase(BaseTestCase):
@@ -604,13 +576,13 @@ class OctetStringTestCase(BaseTestCase):
         assert HexDefault() == univ.OctetString(hexValue='FA9823C43E43510DE3422')
 
     def testBinStr(self):
-        assert univ.OctetString(binValue="1000010111101110101111000000111011") == ints2octs((133, 238, 188, 14, 192)), 'bin init fails'
+        assert univ.OctetString(binValue="1000010111101110101111000000111011") == bytes((133, 238, 188, 14, 192)), 'bin init fails'
 
     def testHexStr(self):
-        assert univ.OctetString(hexValue="FA9823C43E43510DE3422") == ints2octs((250, 152, 35, 196, 62, 67, 81, 13, 227, 66, 32)), 'hex init fails'
+        assert univ.OctetString(hexValue="FA9823C43E43510DE3422") == bytes((250, 152, 35, 196, 62, 67, 81, 13, 227, 66, 32)), 'hex init fails'
 
     def testTuple(self):
-        assert univ.OctetString((1, 2, 3, 4, 5)) == ints2octs((1, 2, 3, 4, 5)), 'tuple init failed'
+        assert univ.OctetString((1, 2, 3, 4, 5)) == bytes((1, 2, 3, 4, 5)), 'tuple init failed'
 
     def testRepr(self):
         assert 'abc' in repr(univ.OctetString('abc'))
@@ -634,7 +606,7 @@ class OctetStringTestCase(BaseTestCase):
         class OctetString(univ.OctetString):
             pass
 
-        assert OctetString(hexValue="FA9823C43E43510DE3422") == ints2octs((250, 152, 35, 196, 62, 67, 81, 13, 227, 66, 32))
+        assert OctetString(hexValue="FA9823C43E43510DE3422") == bytes((250, 152, 35, 196, 62, 67, 81, 13, 227, 66, 32))
 
 
 class OctetStringPicklingTestCase(unittest.TestCase):
@@ -659,10 +631,10 @@ class Null(BaseTestCase):
 
     def testInit(self):
         assert not univ.Null().isValue
-        assert univ.Null(0) == str2octs('')
-        assert univ.Null(False) == str2octs('')
-        assert univ.Null('') == str2octs('')
-        assert univ.Null(None) == str2octs('')
+        assert univ.Null(0) == b''
+        assert univ.Null(False) == b''
+        assert univ.Null('') == b''
+        assert univ.Null(None) == b''
 
         try:
             assert univ.Null(True)
@@ -908,8 +880,6 @@ class ObjectIdentifier(BaseTestCase):
 
     def testUnicode(self):
         s = '1.3.6'
-        if sys.version_info[0] < 3:
-            s = s.decode()
         assert univ.ObjectIdentifier(s) == (1, 3, 6), 'unicode init fails'
 
     def testTag(self):
@@ -949,6 +919,81 @@ class ObjectIdentifierPicklingTestCase(unittest.TestCase):
         assert new_asn1 == (2, 3, 1, 1, 2)
 
 
+class RelativeOID(BaseTestCase):
+    def testStr(self):
+        assert str(univ.RelativeOID((1, 3, 6))) == '1.3.6', 'str() fails'
+
+    def testRepr(self):
+        assert '1.3.6' in repr(univ.RelativeOID('1.3.6'))
+
+    def testEq(self):
+        assert univ.RelativeOID((1, 3, 6)) == (1, 3, 6), '__cmp__() fails'
+
+    def testAdd(self):
+        assert univ.RelativeOID((1, 3)) + (6,) == (1, 3, 6), '__add__() fails'
+
+    def testRadd(self):
+        assert (1,) + univ.RelativeOID((3, 6)) == (1, 3, 6), '__radd__() fails'
+
+    def testLen(self):
+        assert len(univ.RelativeOID((1, 3))) == 2, '__len__() fails'
+
+    def testPrefix(self):
+        o = univ.RelativeOID('1.3.6')
+        assert o.isPrefixOf((1, 3, 6)), 'isPrefixOf() fails'
+        assert o.isPrefixOf((1, 3, 6, 1)), 'isPrefixOf() fails'
+        assert not o.isPrefixOf((1, 3)), 'isPrefixOf() fails'
+
+    def testInput1(self):
+        assert univ.RelativeOID('1.3.6') == (1, 3, 6), 'prettyIn() fails'
+
+    def testInput2(self):
+        assert univ.RelativeOID((1, 3, 6)) == (1, 3, 6), 'prettyIn() fails'
+
+    def testInput3(self):
+        assert univ.RelativeOID(univ.RelativeOID('1.3') + (6,)) == (1, 3, 6), 'prettyIn() fails'
+
+    def testUnicode(self):
+        s = '1.3.6'
+        assert univ.RelativeOID(s) == (1, 3, 6), 'unicode init fails'
+
+    def testTag(self):
+        assert univ.RelativeOID().tagSet == tag.TagSet(
+            (),
+            tag.Tag(tag.tagClassUniversal, tag.tagFormatSimple, 0x0d)
+        )
+
+    def testContains(self):
+        s = univ.RelativeOID('1.3.6.1234.99999')
+        assert 1234 in s
+        assert 4321 not in s
+
+    def testStaticDef(self):
+
+        class RelOID(univ.ObjectIdentifier):
+            pass
+
+        assert str(RelOID((1, 3, 6))) == '1.3.6'
+
+
+class RelativeOIDPicklingTestCase(unittest.TestCase):
+
+    def testSchemaPickling(self):
+        old_asn1 = univ.RelativeOID()
+        serialised = pickle.dumps(old_asn1)
+        assert serialised
+        new_asn1 = pickle.loads(serialised)
+        assert type(new_asn1) == univ.RelativeOID
+        assert old_asn1.isSameTypeWith(new_asn1)
+
+    def testValuePickling(self):
+        old_asn1 = univ.RelativeOID('2.3.1.1.2')
+        serialised = pickle.dumps(old_asn1)
+        assert serialised
+        new_asn1 = pickle.loads(serialised)
+        assert new_asn1 == (2, 3, 1, 1, 2)
+
+
 class SequenceOf(BaseTestCase):
     def setUp(self):
         BaseTestCase.setUp(self)
@@ -968,9 +1013,9 @@ class SequenceOf(BaseTestCase):
 
     def testSeq(self):
         self.s1.setComponentByPosition(0, univ.OctetString('abc'))
-        assert self.s1[0] == str2octs('abc'), 'set by idx fails'
+        assert self.s1[0] == b'abc', 'set by idx fails'
         self.s1[0] = 'cba'
-        assert self.s1[0] == str2octs('cba'), 'set by idx fails'
+        assert self.s1[0] == b'cba', 'set by idx fails'
 
     def testCmp(self):
         self.s1.clear()
@@ -982,11 +1027,11 @@ class SequenceOf(BaseTestCase):
     def testSubtypeSpec(self):
         s = self.s1.clone(
             componentType=univ.OctetString().subtype(
-                subtypeSpec=constraint.SingleValueConstraint(str2octs('abc'))))
+                subtypeSpec=constraint.SingleValueConstraint(b'abc')))
         try:
             s.setComponentByPosition(
                 0, univ.OctetString().subtype(
-                    'abc', subtypeSpec=constraint.SingleValueConstraint(str2octs('abc'))))
+                    'abc', subtypeSpec=constraint.SingleValueConstraint(b'abc')))
         except PyAsn1Error:
             assert 0, 'constraint fails'
         try:
@@ -1014,7 +1059,7 @@ class SequenceOf(BaseTestCase):
     def testComponentConstraintsMatching(self):
         s = self.s1.clone()
         o = univ.OctetString().subtype(
-            subtypeSpec=constraint.ConstraintsUnion(constraint.SingleValueConstraint(str2octs('cba'))))
+            subtypeSpec=constraint.ConstraintsUnion(constraint.SingleValueConstraint(b'cba')))
         s.strictConstraints = True  # This requires types equality
         try:
             s.setComponentByPosition(0, o.clone('cba'))
@@ -1082,25 +1127,25 @@ class SequenceOf(BaseTestCase):
     def testGetItemSlice(self):
         s = self.s1.clone()
         s.extend(['xxx', 'yyy', 'zzz'])
-        assert s[:1] == [str2octs('xxx')]
-        assert s[-2:] == [str2octs('yyy'), str2octs('zzz')]
-        assert s[1:2] == [str2octs('yyy')]
+        assert s[:1] == [b'xxx']
+        assert s[-2:] == [b'yyy', b'zzz']
+        assert s[1:2] == [b'yyy']
 
     def testSetItem(self):
         s = self.s1.clone()
         s.append('xxx')
         s[2] = 'yyy'
         assert len(s) == 3
-        assert s[1] == str2octs('')
+        assert s[1] == b''
 
     def testSetItemSlice(self):
         s = self.s1.clone()
         s[:1] = ['xxx']
-        assert s == [str2octs('xxx')]
+        assert s == [b'xxx']
         s[-2:] = ['yyy', 'zzz']
-        assert s == [str2octs('yyy'), str2octs('zzz')]
+        assert s == [b'yyy', b'zzz']
         s[1:2] = ['yyy']
-        assert s == [str2octs('yyy'), str2octs('yyy')]
+        assert s == [b'yyy', b'yyy']
         assert len(s) == 2
 
     def testAppend(self):
@@ -1109,7 +1154,7 @@ class SequenceOf(BaseTestCase):
         assert len(self.s1) == 1
         self.s1.append('def')
         assert len(self.s1) == 2
-        assert list(self.s1) == [str2octs(x) for x in ['abc', 'def']]
+        assert list(self.s1) == [b'abc', b'def']
 
     def testExtend(self):
         self.s1.clear()
@@ -1117,31 +1162,31 @@ class SequenceOf(BaseTestCase):
         assert len(self.s1) == 1
         self.s1.extend(['def', 'ghi'])
         assert len(self.s1) == 3
-        assert list(self.s1) == [str2octs(x) for x in ['abc', 'def', 'ghi']]
+        assert list(self.s1) == [b'abc', b'def', b'ghi']
 
     def testCount(self):
         self.s1.clear()
         for x in ['abc', 'def', 'abc']:
             self.s1.append(x)
-        assert self.s1.count(str2octs('abc')) == 2
-        assert self.s1.count(str2octs('def')) == 1
-        assert self.s1.count(str2octs('ghi')) == 0
+        assert self.s1.count(b'abc') == 2
+        assert self.s1.count(b'def') == 1
+        assert self.s1.count(b'ghi') == 0
 
     def testIndex(self):
         self.s1.clear()
         for x in ['abc', 'def', 'abc']:
             self.s1.append(x)
-        assert self.s1.index(str2octs('abc')) == 0
-        assert self.s1.index(str2octs('def')) == 1
-        assert self.s1.index(str2octs('abc'), 1) == 2
+        assert self.s1.index(b'abc') == 0
+        assert self.s1.index(b'def') == 1
+        assert self.s1.index(b'abc', 1) == 2
 
     def testSort(self):
         self.s1.clear()
         self.s1[0] = 'b'
         self.s1[1] = 'a'
-        assert list(self.s1) == [str2octs('b'), str2octs('a')]
+        assert list(self.s1) == [b'b', b'a']
         self.s1.sort()
-        assert list(self.s1) == [str2octs('a'), str2octs('b')]
+        assert list(self.s1) == [b'a', b'b']
 
     def testStaticDef(self):
 
@@ -1151,7 +1196,7 @@ class SequenceOf(BaseTestCase):
         s = SequenceOf()
         s[0] = 'abc'
         assert len(s) == 1
-        assert s == [str2octs('abc')]
+        assert s == [b'abc']
 
     def testUntyped(self):
         n = univ.SequenceOf()
@@ -1187,7 +1232,7 @@ class SequenceOf(BaseTestCase):
         assert s.getComponentByPosition(0, default=None) is None
         s[0] = 'test'
         assert s.getComponentByPosition(0, default=None) is not None
-        assert s.getComponentByPosition(0, default=None) == str2octs('test')
+        assert s.getComponentByPosition(0, default=None) == b'test'
         s.clear()
         assert s.getComponentByPosition(0, default=None) is None
 
@@ -1200,7 +1245,7 @@ class SequenceOf(BaseTestCase):
         assert s.getComponentByPosition(0, instantiate=False) is univ.noValue
         s[0] = 'test'
         assert s.getComponentByPosition(0, instantiate=False) is not univ.noValue
-        assert s.getComponentByPosition(0, instantiate=False) == str2octs('test')
+        assert s.getComponentByPosition(0, instantiate=False) == b'test'
         s.clear()
         assert s.getComponentByPosition(0, instantiate=False) is univ.noValue
 
@@ -1212,7 +1257,7 @@ class SequenceOf(BaseTestCase):
         s = SequenceOf()
         s.setComponentByPosition(0, 'test')
 
-        assert s.getComponentByPosition(0) == str2octs('test')
+        assert s.getComponentByPosition(0) == b'test'
         assert len(s) == 1
         assert s.isValue
 
@@ -1230,7 +1275,7 @@ class SequenceOf(BaseTestCase):
         s = SequenceOf()
         s.setComponentByPosition(0, 'test')
 
-        assert s.getComponentByPosition(0) == str2octs('test')
+        assert s.getComponentByPosition(0) == b'test'
         assert s.isValue
 
         s.reset()
@@ -1286,7 +1331,7 @@ class SequenceOfPicklingTestCase(unittest.TestCase):
         assert serialised
         new_asn1 = pickle.loads(serialised)
         assert new_asn1
-        assert new_asn1 == [str2octs('test')]
+        assert new_asn1 == [b'test']
 
 
 class Sequence(BaseTestCase):
@@ -1311,11 +1356,11 @@ class Sequence(BaseTestCase):
 
     def testById(self):
         self.s1.setComponentByName('name', univ.OctetString('abc'))
-        assert self.s1.getComponentByName('name') == str2octs('abc'), 'set by name fails'
+        assert self.s1.getComponentByName('name') == b'abc', 'set by name fails'
 
     def testByKey(self):
         self.s1['name'] = 'abc'
-        assert self.s1['name'] == str2octs('abc'), 'set by key fails'
+        assert self.s1['name'] == b'abc', 'set by key fails'
 
     def testContains(self):
         assert 'name' in self.s1
@@ -1363,7 +1408,7 @@ class Sequence(BaseTestCase):
     def testComponentConstraintsMatching(self):
         s = self.s1.clone()
         o = univ.OctetString().subtype(
-            subtypeSpec=constraint.ConstraintsUnion(constraint.SingleValueConstraint(str2octs('cba'))))
+            subtypeSpec=constraint.ConstraintsUnion(constraint.SingleValueConstraint(b'cba')))
         s.strictConstraints = True  # This requires types equality
         try:
             s.setComponentByName('name', o.clone('cba'))
@@ -1451,23 +1496,23 @@ class Sequence(BaseTestCase):
         self.s1.setComponentByPosition(0, univ.OctetString('abc'))
         self.s1.setComponentByPosition(1, univ.OctetString('def'))
         self.s1.setComponentByPosition(2, univ.Integer(123))
-        assert list(self.s1.values()) == [str2octs('abc'), str2octs('def'), 123]
+        assert list(self.s1.values()) == [b'abc', b'def', 123]
 
     def testItems(self):
         self.s1.setComponentByPosition(0, univ.OctetString('abc'))
         self.s1.setComponentByPosition(1, univ.OctetString('def'))
         self.s1.setComponentByPosition(2, univ.Integer(123))
-        assert list(self.s1.items()) == [(x[0], str2octs(x[1])) for x in [('name', 'abc'), ('nick', 'def')]] + [('age', 123)]
+        assert list(self.s1.items()) == [('name', b'abc'), ('nick', b'def'), ('age', 123)]
 
     def testUpdate(self):
         self.s1.clear()
-        assert list(self.s1.values()) == [str2octs(''), str2octs(''), 34]
+        assert list(self.s1.values()) == [b'', b'', 34]
         self.s1.update(**{'name': 'abc', 'nick': 'def', 'age': 123})
-        assert list(self.s1.items()) == [(x[0], str2octs(x[1])) for x in [('name', 'abc'), ('nick', 'def')]] + [('age', 123)]
+        assert list(self.s1.items()) == [('name', b'abc'), ('nick', b'def'), ('age', 123)]
         self.s1.update(('name', 'ABC'))
-        assert list(self.s1.items()) == [(x[0], str2octs(x[1])) for x in [('name', 'ABC'), ('nick', 'def')]] + [('age', 123)]
+        assert list(self.s1.items()) == [('name', b'ABC'), ('nick', b'def'), ('age', 123)]
         self.s1.update(name='CBA')
-        assert list(self.s1.items()) == [(x[0], str2octs(x[1])) for x in [('name', 'CBA'), ('nick', 'def')]] + [('age', 123)]
+        assert list(self.s1.items()) == [('name', b'CBA'), ('nick', b'def'), ('age', 123)]
 
     def testStaticDef(self):
 
@@ -1480,7 +1525,7 @@ class Sequence(BaseTestCase):
 
         s = Sequence()
         s['name'] = 'abc'
-        assert s['name'] == str2octs('abc')
+        assert s['name'] == b'abc'
 
     def testGetComponentWithDefault(self):
 
@@ -1492,12 +1537,12 @@ class Sequence(BaseTestCase):
 
         s = Sequence()
 
-        assert s[0] == str2octs('')
+        assert s[0] == b''
         assert s.getComponentByPosition(1, default=None, instantiate=False) is None
         assert s.getComponentByName('nick', default=None) is None
         s[1] = 'test'
         assert s.getComponentByPosition(1, default=None) is not None
-        assert s.getComponentByPosition(1, default=None) == str2octs('test')
+        assert s.getComponentByPosition(1, default=None) == b'test'
         s.clear()
         assert s.getComponentByPosition(1, default=None) is None
 
@@ -1526,12 +1571,12 @@ class Sequence(BaseTestCase):
             )
 
         s = Sequence()
-        assert s[0] == str2octs('')
+        assert s[0] == b''
         assert s.getComponentByPosition(1, instantiate=False) is univ.noValue
         assert s.getComponentByName('nick', instantiate=False) is univ.noValue
         s[1] = 'test'
         assert s.getComponentByPosition(1, instantiate=False) is not univ.noValue
-        assert s.getComponentByPosition(1, instantiate=False) == str2octs('test')
+        assert s.getComponentByPosition(1, instantiate=False) == b'test'
         s.clear()
         assert s.getComponentByPosition(1, instantiate=False) is univ.noValue
 
@@ -1558,29 +1603,6 @@ class Sequence(BaseTestCase):
 
         assert not s.isValue
 
-    def testSchemaWithOptionalComponents(self):
-
-        class Sequence(univ.Sequence):
-            componentType = namedtype.NamedTypes(
-                namedtype.OptionalNamedType('name', univ.OctetString())
-            )
-
-        s = Sequence()
-
-        assert s.isValue
-
-        s[0] = 'test'
-
-        assert s.isValue
-
-        s.clear()
-
-        assert s.isValue
-
-        s.reset()
-
-        assert not s.isValue
-
     def testSchemaWithOptionalComponents(self):
 
         class Sequence(univ.Sequence):
@@ -1725,13 +1747,13 @@ class SequenceWithoutSchema(BaseTestCase):
         s = univ.Sequence()
         s.setComponentByPosition(0, univ.OctetString('abc'))
         s.setComponentByPosition(1, univ.Integer(123))
-        assert list(s.values()) == [str2octs('abc'), 123]
+        assert list(s.values()) == [b'abc', 123]
 
     def testItems(self):
         s = univ.Sequence()
         s.setComponentByPosition(0, univ.OctetString('abc'))
         s.setComponentByPosition(1, univ.Integer(123))
-        assert list(s.items()) == [('field-0', str2octs('abc')), ('field-1', 123)]
+        assert list(s.items()) == [('field-0', b'abc'), ('field-1', 123)]
 
     def testUpdate(self):
         s = univ.Sequence().clear()
@@ -1740,12 +1762,12 @@ class SequenceWithoutSchema(BaseTestCase):
         s.setComponentByPosition(1, univ.Integer(123))
         assert s
         assert list(s.keys()) == ['field-0', 'field-1']
-        assert list(s.values()) == [str2octs('abc'), 123]
-        assert list(s.items()) == [('field-0', str2octs('abc')), ('field-1', 123)]
+        assert list(s.values()) == [b'abc', 123]
+        assert list(s.items()) == [('field-0', b'abc'), ('field-1', 123)]
         s['field-0'] = univ.OctetString('def')
-        assert list(s.values()) == [str2octs('def'), 123]
+        assert list(s.values()) == [b'def', 123]
         s['field-1'] = univ.OctetString('ghi')
-        assert list(s.values()) == [str2octs('def'), str2octs('ghi')]
+        assert list(s.values()) == [b'def', b'ghi']
         try:
             s['field-2'] = univ.OctetString('xxx')
         except KeyError:
@@ -1803,7 +1825,7 @@ class SequencePicklingTestCase(unittest.TestCase):
         assert serialised
         new_asn1 = pickle.loads(serialised)
         assert new_asn1
-        assert new_asn1['name'] == str2octs('test')
+        assert new_asn1['name'] == b'test'
 
 
 class SetOf(BaseTestCase):
@@ -1819,9 +1841,9 @@ class SetOf(BaseTestCase):
 
     def testSeq(self):
         self.s1.setComponentByPosition(0, univ.OctetString('abc'))
-        assert self.s1[0] == str2octs('abc'), 'set by idx fails'
+        assert self.s1[0] == b'abc', 'set by idx fails'
         self.s1.setComponentByPosition(0, self.s1[0].clone('cba'))
-        assert self.s1[0] == str2octs('cba'), 'set by idx fails'
+        assert self.s1[0] == b'cba', 'set by idx fails'
 
     def testStaticDef(self):
 
@@ -1831,7 +1853,7 @@ class SetOf(BaseTestCase):
         s = SetOf()
         s[0] = 'abc'
         assert len(s) == 1
-        assert s == [str2octs('abc')]
+        assert s == [b'abc']
 
 
 
@@ -1852,7 +1874,7 @@ class SetOfPicklingTestCase(unittest.TestCase):
         assert serialised
         new_asn1 = pickle.loads(serialised)
         assert new_asn1
-        assert new_asn1 == [str2octs('test')]
+        assert new_asn1 == [b'test']
 
 
 class Set(BaseTestCase):
@@ -1878,13 +1900,13 @@ class Set(BaseTestCase):
         self.s1.setComponentByType(univ.OctetString.tagSet, 'abc')
         assert self.s1.getComponentByType(
             univ.OctetString.tagSet
-        ) == str2octs('abc'), 'set by name fails'
+        ) == b'abc', 'set by name fails'
 
     def testByTypeWithInstance(self):
         self.s1.setComponentByType(univ.OctetString.tagSet, univ.OctetString('abc'))
         assert self.s1.getComponentByType(
             univ.OctetString.tagSet
-        ) == str2octs('abc'), 'set by name fails'
+        ) == b'abc', 'set by name fails'
 
     def testGetTagMap(self):
         assert self.s1.tagMap.presentTypes == {
@@ -1919,7 +1941,7 @@ class Set(BaseTestCase):
 
         s = Set()
         s['name'] = 'abc'
-        assert s['name'] == str2octs('abc')
+        assert s['name'] == b'abc'
 
     def testGetComponentWithDefault(self):
 
@@ -1935,7 +1957,7 @@ class Set(BaseTestCase):
         assert s.getComponentByName('nick', default=None) is None
         s[1] = 'test'
         assert s.getComponentByPosition(1, default=None) is not None
-        assert s.getComponentByPosition(1, default=None) == str2octs('test')
+        assert s.getComponentByPosition(1, default=None) == b'test'
         s.clear()
         assert s.getComponentByPosition(1, default=None) is None
 
@@ -1954,7 +1976,7 @@ class Set(BaseTestCase):
         assert s.getComponentByType(univ.OctetString.tagSet, instantiate=False) is univ.noValue
         s[1] = 'test'
         assert s.getComponentByPosition(1, instantiate=False) is not univ.noValue
-        assert s.getComponentByPosition(1, instantiate=False) == str2octs('test')
+        assert s.getComponentByPosition(1, instantiate=False) == b'test'
         s.clear()
         assert s.getComponentByPosition(1, instantiate=False) is univ.noValue
 
@@ -1984,7 +2006,7 @@ class SetPicklingTestCase(unittest.TestCase):
         assert serialised
         new_asn1 = pickle.loads(serialised)
         assert new_asn1
-        assert new_asn1['name'] == str2octs('test')
+        assert new_asn1['name'] == b'test'
 
 
 class Choice(BaseTestCase):
@@ -2033,7 +2055,7 @@ class Choice(BaseTestCase):
         self.s1.setComponentByType(univ.OctetString.tagSet, 'abc')
         assert self.s1.getComponentByType(
             univ.OctetString.tagSet
-        ) == str2octs('abc')
+        ) == b'abc'
 
     def testOuterByTypeWithInstanceValue(self):
         self.s1.setComponentByType(
@@ -2041,7 +2063,7 @@ class Choice(BaseTestCase):
         )
         assert self.s1.getComponentByType(
             univ.OctetString.tagSet
-        ) == str2octs('abc')
+        ) == b'abc'
 
     def testInnerByTypeWithPythonValue(self):
         self.s1.setComponentByType(univ.Integer.tagSet, 123, innerFlag=True)
@@ -2059,11 +2081,11 @@ class Choice(BaseTestCase):
 
     def testCmp(self):
         self.s1.setComponentByName('name', univ.OctetString('abc'))
-        assert self.s1 == str2octs('abc'), '__cmp__() fails'
+        assert self.s1 == b'abc', '__cmp__() fails'
 
     def testGetComponent(self):
         self.s1.setComponentByType(univ.OctetString.tagSet, 'abc')
-        assert self.s1.getComponent() == str2octs('abc'), 'getComponent() fails'
+        assert self.s1.getComponent() == b'abc', 'getComponent() fails'
 
     def testGetName(self):
         self.s1.setComponentByType(univ.OctetString.tagSet, 'abc')
@@ -2071,7 +2093,7 @@ class Choice(BaseTestCase):
 
     def testSetComponentByPosition(self):
         self.s1.setComponentByPosition(0, univ.OctetString('Jim'))
-        assert self.s1 == str2octs('Jim')
+        assert self.s1 == b'Jim'
 
     def testClone(self):
         self.s1.setComponentByPosition(0, univ.OctetString('abc'))
@@ -2175,7 +2197,7 @@ class ChoicePicklingTestCase(unittest.TestCase):
         assert serialised
         new_asn1 = pickle.loads(serialised)
         assert new_asn1
-        assert new_asn1['name'] == str2octs('test')
+        assert new_asn1['name'] == b'test'
 
 
 suite = unittest.TestLoader().loadTestsFromModule(sys.modules[__name__])
